@@ -24,31 +24,37 @@ _postImportVars = vars().keys()
 
 class CookieInstaller(object):
 	"""
-	Gets or sets a session cookie on a L{twisted.web.server.Request} object.
+	Gets or sets an 16-byte identifier cookie on a L{twisted.web.server.Request}
+	object.
 	"""
-	__slots__ = ('_secureRandom',)
-
-	# Sent to HTTP and HTTPS.
-	insecureCookieName = '__'
-
-	# Sent only over HTTPS. The cookie name is different so that it does not collide.
-	secureCookieName = '_s'
-
-	expires = 'Sat, 08 Dec 2029 23:55:42 GMT' # copied from Amazon
-
-	path = '/'
-
-	domain = None
+	__slots__ = ('_secureRandom', '_insecureName', '_secureName', '_domain',
+		'_path', '_expires')
 
 	# TODO: maybe add some functionality to get/set the insecure cookie
 	# during HTTPS requests as well.
 
-	def __init__(self, secureRandom):
+	def __init__(self, secureRandom, insecureName, secureName,
+	domain=None, path='/', expires='Sat, 08 Dec 2029 23:55:42 GMT'):
 		"""
-		C{secureRandom} is a 1-argument (# of bytes) callable that returns a
-			string of # random bytes.
+		@param secureRandom: a 1-argument (# of bytes) callable that
+			returns a string of # random bytes.  You probably want to
+			pass L{os.urandom}.
+		@type secureRandom: function
+
+		@param insecureName: the cookie name for a cookie that will be sent by
+			client for both HTTP and HTTPS requests.
+		@type insecureName: C{str}
+
+		@param secureName: the cookie name for a cookie that will be sent by
+			client for HTTPS requests.  Don't use the same name as C{insecureName}.
+		@type secureName: C{str}
 		"""
 		self._secureRandom = secureRandom
+		self._insecureName = insecureName
+		self._secureName = secureName
+		self._domain = domain
+		self._path = path
+		self._expires = expires
 
 
 	def getSet(self, request):
@@ -68,16 +74,17 @@ class CookieInstaller(object):
 		"""
 		secure = request.isSecure()
 		if secure:
-			k = self.secureCookieName
+			k = self._secureName
 		else:
-			k = self.insecureCookieName
+			k = self._insecureName
 
 		existingCookie = request.getCookie(k)
 
-		# If we allow base64 without padding, change to allow both 22 and 24.
+		# If we ever allow base64 without padding, change to allow both 22 and 24.
 		if existingCookie and len(existingCookie) == 24:
 			try:
-				# Keep in mind that a2b_base64 will skip over non-base64-alphabet characters.
+				# Keep in mind that a2b_base64 will skip over
+				# non-base64-alphabet characters.
 				decoded = binascii.a2b_base64(existingCookie)
 				if len(decoded) == 16:
 					return decoded
@@ -86,7 +93,8 @@ class CookieInstaller(object):
 
 		rand = self._secureRandom(16)
 		v = binascii.b2a_base64(rand).rstrip('\n')
-		request.addCookie(k, v, expires=self.expires, domain=self.domain, path=self.path, secure=secure)
+		request.addCookie(k, v, expires=self._expires, domain=self._domain,
+			path=self._path, secure=secure)
 		return rand
 
 
@@ -138,7 +146,8 @@ def setNoCacheNoStoreHeaders(request):
 	setRawHeaders = request.responseHeaders.setRawHeaders
 
 	# Headers are similar to the ones gmail sends
-	setRawHeaders('cache-control', ['no-cache, no-store, max-age=0, must-revalidate'])
+	setRawHeaders('cache-control', [
+		'no-cache, no-store, max-age=0, must-revalidate'])
 	setRawHeaders('pragma', ['no-cache'])
 	setRawHeaders('expires', ['-1'])
 
